.. _spkg_mathjax:

mathjax: A JavaScript library for displaying mathematical formulas
============================================================================

Description
-----------

MathJax is a JavaScript library for displaying mathematical formulas.

MathJax is used in the Sage documentation built by Sphinx.

License
-------

Apache License, version 2.0

Upstream Contact
----------------

Home page: https://www.mathjax.org/

Type
----

standard


Dependencies
------------


Version Information
-------------------

package-version.txt::

    3.2.0


Equivalent System Packages
--------------------------

.. tab:: conda-forge

   .. CODE-BLOCK:: bash

       $ conda install mathjax 


.. tab:: Fedora/Redhat/CentOS

   .. CODE-BLOCK:: bash

       $ sudo dnf install mathjax3 


.. tab:: Gentoo Linux

   .. CODE-BLOCK:: bash

       $ sudo emerge \>=dev-libs/mathjax-3 


.. tab:: openSUSE

   .. CODE-BLOCK:: bash

       $ sudo zypper install mathjax 


.. tab:: Void Linux

   .. CODE-BLOCK:: bash

       $ sudo xbps-install mathjax 



See https://repology.org/project/mathjax/versions

If the system package is installed, ``./configure`` will check if it can be used.

